@@ -99,14 +99,21 @@ class LangDivision(Base):
     """
     Модель "Языковый отдел"
     """
-
     __tablename__ = 'univer_lang_division'
 
+    # Идентификатор
     id = Column('lang_division_id', Integer, primary_key=True)
+
+    # Наименование
     name_ru = Column('lang_division_name_ru', String(100))
+    name_kz = Column('lang_division_name_kz', String(100))
+    name_en = Column('lang_division_name_en', String(100))
+
+    # Статус
+    status = Column(Integer)
 
     def __repr__(self):
-        return '<LangDivision {}>'.format(self.name_ru)
+        return '<LangDivision {} (id={}, status={})>'.format(self, self.id, self.status)
 
     def __str__(self):
         return self.name_ru
@@ -472,6 +479,8 @@ class Controll(Base):
 
     # Наименование
     name_ru = Column('control_name_ru', String(100))
+    name_kz = Column('control_name_kz', String(100))
+    name_en = Column('control_name_en', String(100))
 
     def __repr__(self):
         return '<Controll {} (id={})>'.format(self, self.id)
